{"00000:1": "

    {% extends '_base.html' -%}\n\n{% block banner -%}\n{% endblock -%}\n\n{% block mainpage -%}\n<div id="page-wrapper">\n    <div class="divider"></div>\n    <div class="12u">\n        <div class="5grid-layout" id="onecolumn">\n            <div class="row">\n                <div class="12u">\n                    <section>\n                    <div class="post">\n                        {{ content }}\n                    </div>\n                    </section>\n                </div>\n            </div>\n        </div>\n    </div>\n</div>\n{% endblock -%}\n

\n"}